from .mydb import MyDB

# 比赛
class BSTMatch:
  def __init__(self,
               # 比赛周编码
               matchWeek,

               # 比赛时间
               matchTime,

               # 联赛
               league,

               # 主队
               homeTeam,

               # 客队
               awayTeam,

               # 开售状态
               status,

               # 胜负
               wl,

               # 胜负(让)
               wls,

               # 大小分
               score,

               # 剩分差
               points
               ):
    self.matchWeek = matchWeek
    self.matchTime = matchTime
    self.league = league
    self.homeTeam = homeTeam
    self.awayTeam = awayTeam
    self.status = status
    self.wl = wl
    self.wls = wls
    self.score = score
    self.points = points

  def toString(self):
    return ";".join((
      self.matchWeek,
      self.matchTime,
      self.league,
      self.homeTeam,
      self.awayTeam,
      self.status,
      self.wl,
      self.wls,
      self.score,
      self.points
    ))

  def persist(self):
    cursor = MyDB.getCursor()
    if cursor is None:
      return

    sql = "insert into ta_crawl_ball(ball_type, data_type, content) values('basketball', 'match', %s)"
    cursor.execute(sql, self.toString())
    MyDB.commit()
    cursor.close()


# 赔率
class BSTPrice:
  def __init__(self,
               # 比赛ID
               matchId,

               # 比赛周编码
               matchWeek,

               # 比赛时间
               matchTime,

               # 联赛
               league,

               # 主队
               homeTeam,

               # 客队
               awayTeam,

               # 胜负
               wlOdds=None,

               # 胜负(让) - [w, l, s]
               wlsOdds=None,

               # 大小分 - [大, 小, 总分]
               scoreResult=None,

               # 剩分差 - [主胜6 + 客胜 6]
               pointsResult=None
               ):
    self.matchId = matchId
    self.matchWeek = matchWeek
    self.matchTime = matchTime
    self.league = league
    self.homeTeam = homeTeam
    self.awayTeam = awayTeam
    self.wlOdds = wlOdds
    self.wlsOdds = wlsOdds
    self.scoreResult = scoreResult
    self.pointsResult = pointsResult

  def toString(self):
    return ";".join((
      self.matchId,
      self.matchWeek,
      self.matchTime,
      self.league,
      self.homeTeam,
      self.awayTeam,
      self.wlOdds.toString(),
      self.wlsOdds.toString(),
      self.scoreResult.toString(),
      self.pointsResult.toString()
    ))

  def persist(self):
    cursor = MyDB.getCursor()
    if cursor is None:
      return

    sql = "insert into ta_crawl_ball(ball_type, data_type, content) values('basketball', 'price', %s)"
    cursor.execute(sql, self.toString())
    MyDB.commit()
    cursor.close()


# 胜平负
class WLOdds:
  def __init__(self,
               # 胜
               win=None,

               # 负
               lose=None
               ):
    self.win = win
    self.lose = lose

  def datas(self, datas=[]):
    self.win = datas[0]
    self.lose = datas[1]

  def toString(self):
    return '|'.join((self.win, self.lose))


# 胜平负(让)
class WLSpreadOdds:
  def __init__(self,
               # 胜
               win=None,

               # 负
               lose=None,

               # 让球
               spread=None
               ):
    self.win = win
    self.lose = lose
    self.spread = spread

  def datas(self, datas=[]):
    self.win = datas[0]
    self.lose = datas[1]
    self.spread = datas[2]

  def toString(self):
    return '|'.join((self.win, self.lose, self.spread))


# 大小分
class ScoreResult:
  def __init__(self,
               big = None, # 大
               small = None, # 小
               total = None # 预设总分
               ):
    self.big = big
    self.small = small
    self.total = total

  def toString(self):
    return '|'.join((
      self.big,
      self.small,
      self.total)
    )

# 剩分差
class PointsResult:
  def __init__(self,
               w15=None,  # 胜 1-5
               w610=None,  # 胜 6-10
               w1115=None,  # 胜 11-15
               w1620=None,  # 胜 16-20
               w2125=None,  # 胜 21-25
               w99=None,  # 胜 26+
               l15=None,  # 负 1-5
               l610=None,  # 负 6-10
               l1115=None,  # 负 11-15
               l1620=None,  # 负 16-20
               l2125=None,  # 负 21-25
               l99=None  # 负 26+
               ):
    self.w15 = w15
    self.w610 = w610
    self.w1115 = w1115
    self.w1620 = w1620
    self.w2125 = w2125
    self.w99 = w99
    self.l15 = l15
    self.l610 = l610
    self.l1115 = l1115
    self.l1620 = l1620
    self.l2125 = l2125
    self.l99 = l99

  def datas(self, datas=[]):
    self.w15 = datas[0]
    self.w610 = datas[1]
    self.w1115 = datas[2]
    self.w1620 = datas[3]
    self.w2125 = datas[4]
    self.w99 = datas[5]
    self.l15 = datas[6]
    self.l610 = datas[7]
    self.l1115 = datas[8]
    self.l1620 = datas[9]
    self.l2125 = datas[10]
    self.l99 = datas[11]

  def toString(self):
    return '|'.join((
      self.w15,
      self.w610,
      self.w1115,
      self.w1620,
      self.w2125,
      self.w99,
      self.l15,
      self.l610,
      self.l1115,
      self.l1620,
      self.l2125,
      self.l99)
    )


# 结果
class BSTResult:
  def __init__(self,
               # 比赛时间
               matchTime,

               # 周次
               matchWeek,

               # 联赛
               league,

               # 主队
               homeTeam,

               # 客队
               awayTeam,

               # 是否单固场次
               single,

               # 比分
               score,

               # 状态
               status
               ):
    self.matchTime = matchTime
    self.matchWeek = matchWeek
    self.league = league
    self.homeTeam = homeTeam
    self.awayTeam = awayTeam
    self.single = single
    self.score = score
    self.status = status

  def toString(self):
    return ';'.join((
      self.matchTime,
      self.matchWeek,
      self.league,
      self.homeTeam,
      self.awayTeam,
      self.single,
      self.score,
      self.status
    ))

  def persist(self):
    cursor = MyDB.getCursor()
    if cursor is None:
      return

    sql = "insert into ta_crawl_ball(ball_type, data_type, content) values('basketball', 'result', %s)"
    cursor.execute(sql, self.toString())
    MyDB.commit()
    cursor.close()
