import scrapy
import time
from crawl.comm.basketball import BSTMatch

class BasketballSpider(scrapy.Spider):
  name = "basketball-match"

  def start_requests(self):
    # 受注比赛
    url = "https://www.lottery.gov.cn/basketball/match_list.jspx"
    yield scrapy.Request(url, self.parseMatch)
  
  def parseMatch(self, response):
    cssMain = ".xxsj table tr"
    cssDetail = "td"

    # 获取所有比赛
    matches = response.css(cssMain)
    for node in matches[1:]:  # 标题行忽略
      prop = node.css(cssDetail)

      # 小于 2 个 td 为无效行
      if len(prop) < 2:
        continue

      matchWeek = prop[0].css('::text').get()
      league = prop[1].css('::text').get()
      team = prop[2].css('::text').get().split('VS')
      homeTeam = team[1].strip()
      awayTeam = team[0].strip()
      matchTime = prop[3].css('::text').get()
      status = prop[5].css('::text').get()
      wl = self.parsePassWay(prop[6].css('img'))
      wls = self.parsePassWay(prop[7].css('img'))
      score = self.parsePassWay(prop[8].css('img'))
      points = self.parsePassWay(prop[9].css('img'))

      BSTMatch(
        matchWeek,
        matchTime,
        league,
        homeTeam,
        awayTeam,
        status,
        wl,
        wls,
        score,
        points
      ).persist()
  
  def parsePassWay(self, img):
    # 待开售
    if img is None:
      return 'wait'

    # 图片地址
    src = img.attrib['src']

    # 开售单关方式和过关方式
    if "ball2_11.png" in src:
      return 'pass&single'

    # 仅开售过关方式
    elif "ball2_1.png" in src:
      return 'pass'

    # 未开售此玩法
    else:
      return 'no'
