import scrapy
import time
from crawl.comm.basketball import BSTPrice, WLOdds, WLSpreadOdds, ScoreResult, PointsResult

class BasketballSpider(scrapy.Spider):
  name = "basketball-price"

  def start_requests(self):
    # 赔率
    url = "https://www.lottery.gov.cn/basketball/counter.jspx"
    yield scrapy.Request(url, self.parsePrice)
  
  def parsePrice(self, response):
    cssMain = "#content .article .articleCon .section"
    cssDetail = ".saishi"
    cssOther = ".saishiCon table td"

    # 获取所有比赛
    matches = response.css(cssMain)
    for node in matches:

      # 比赛ID
      matchId = node.attrib['match_id']
      matchTime = node.attrib['match_time']
      matchWeek = node.attrib['match_week']
      league = node.attrib['league_val']

      # 其他相关属性
      details = node.css(cssDetail).css("td")
      homeTeam = details[4].css('::text').get()
      awayTeam = details[3].css('::text').get()

      match = BSTPrice(
        matchId,
        matchWeek,
        matchTime,
        league,
        homeTeam,
        awayTeam,
        WLOdds(
          details[6].css('strong::text').get(),
          details[5].css('strong::text').get()
        ),
        WLSpreadOdds(
          details[9].css('strong::text').get(),
          details[7].css('strong::text').get(),
          details[8].css('strong font::text').get()
        ),
        ScoreResult(
          details[10].css('strong::text').get(),
          details[12].css('strong::text').get(),
          details[11].css('strong::text').get()
        )
      )

      # 剩分差
      pointsResult = PointsResult()
      datas1 = []
      lst = node.css(cssOther)
      for it1 in lst[9:15]:
        datas1 += [it1.css('strong::text').get()]

      datas2 = []
      for it2 in lst[16:22]:
        datas2 += [it2.css('strong::text').get()]

      pointsResult.datas(datas2 + datas1)
      match.pointsResult = pointsResult

      # 入库
      match.persist()
  