import scrapy
import time
from crawl.comm.football import FTPrice, WDLOdds, WDLSpreadOdds, ScoreResult, PointsResult, DoubleResult

class FootballSpider(scrapy.Spider):
  name = "football-price"

  def start_requests(self):
    # 赔率
    url = "https://www.lottery.gov.cn/football/counter.jspx"
    yield scrapy.Request(url, self.parsePrice)
  
  def parsePrice(self, response):
    cssMain = "#content .article .articleCon .section"
    cssDetail = ".saishi"
    cssOther = ".saishiCon"

    # 获取所有比赛
    matches = response.css(cssMain)
    for node in matches:

      # 比赛ID
      matchId = node.attrib['match_id']
      matchTime = node.attrib['match_time']

      # 其他相关属性
      details = node.css(cssDetail).css("td")
      matchWeek = details[0].css('::text').get()
      league = details[1].css('::text').get()
      homeTeam = details[3].css('::text').get()
      awayTeam = details[4].css('::text').get()

      match = FTPrice(
        matchId,
        matchWeek,
        matchTime,
        league,
        homeTeam,
        awayTeam,
        WDLOdds(
          details[5].css('::text').get(),
          details[6].css('::text').get(),
          details[7].css('::text').get()
        ),
        WDLSpreadOdds(
          details[9].css('::text').get(),
          details[10].css('::text').get(),
          details[11].css('::text').get(),
          details[8].css('::text').get()
        )
      )

      # 比分, 总分, 半全场 是另外的 table
      otherOdds = node.css(cssOther)
      for index, otherNode in enumerate(otherOdds):

        # 获取比分的赔率
        if index == 0:
          scoreResult = ScoreResult()
          datas = []
          lst = otherNode.css('td')

          # table 的 3 个 tr
          for it in lst[1:14] + lst[15:20] + lst[21:34]:
            datas += [it.css('strong::text').get()]

          scoreResult.datas(datas)
          match.scoreResult = scoreResult

        # 获取总分的赔率
        elif index == 1:
          pointsResult = PointsResult()
          datas = []
          lst = otherNode.css('td')

          for it in lst[2:10]:
            datas += [it.css('strong::text').get()]

          pointsResult.datas(datas)
          match.pointsResult = pointsResult

        # 获取半全场赔率
        else:
          doubleResult = DoubleResult()
          datas = []
          lst = otherNode.css('td')

          for it in lst[2:11]:
            datas += [it.css('strong::text').get()]

          doubleResult.datas(datas)
          match.doubleResult = doubleResult

      # 入库
      match.persist()
  