import scrapy
import re
import logging
from crawl.comm.football import FTResult

class FootballSpider(scrapy.Spider):
  name = "football-result"

  def start_requests(self):
    url = 'https://info.sporttery.cn/football/match_result.php'
    yield scrapy.Request(url, self.parseResult, 'GET')

  def parseResult(self, response):
    # 处理比赛结果
    cssOfMatch = '.all-wrap > .match_list .m-tab tr'
    matches = response.css(cssOfMatch)
    if matches is None: return
    for matchNode in matches:
      tdNodeList = matchNode.css('td')
      if tdNodeList is None or len(tdNodeList) < 10:
        continue

      matchTime = tdNodeList[0].css('::text').get()
      matchWeek = tdNodeList[1].css('::text').get()
      league = tdNodeList[2].css('::text').get()
      leagueFullName = tdNodeList[2].attrib.get('title')  # 联赛全称
      leagueName = '|'.join((league if league is not None else '', leagueFullName if leagueFullName is not None else ''))
      homeTeam = self.trimBrackets(tdNodeList[3].css('.zhu::text').get()) # 主队
      awayTeam = self.trimBrackets(tdNodeList[3].css('.ke::text').get()) # 客队
      half = tdNodeList[4].css('span::text').get()
      whole = tdNodeList[5].css('span::text').get()
      status = tdNodeList[9].css('::text').get()

      ftResult = FTResult(
        matchTime,
        matchWeek,
        leagueName,
        homeTeam,
        awayTeam,
        '', # 不需要单固
        half,
        whole,
        status
      )
      
      logging.info("采集到数据 --> %s" % ftResult.toString())

      ftResult.persist()


    # 是否存在下一页
    pgNodes = response.css('.m-page .u-pg2')
    if pgNodes is None or len(pgNodes) < 1: return

    # 总页数
    total = pgNodes[-1].css('a::text').get()
    if total is None or total == '':
      total = 0

    # 当前页数
    current = re.sub(r'^.*match_result.php[?page=]*', '', response.url)
    if current is None or current == '':
      current = 1

    if int(current) >= int(total): return

    # 下一页
    nextPG = int(current) + 1
    url = 'https://info.sporttery.cn/football/match_result.php?page=' + str(nextPG)
    return scrapy.Request(url, self.parseResult, 'GET')


  def trimBrackets(self, str):
    if str is None: return ''

    return re.sub(r'\(.*\)', '', str)
