import scrapy

from crawl.comm.lottery import LotteryResult, LotteryResultDetail


class LotterySpider(scrapy.Spider):
  name = "lottery"

  def start_requests(self):
    # 大乐透
    url = "https://www.lottery.gov.cn/api/lottery_kj_detail_new.jspx?_ltype=4"
    yield scrapy.Request(url, self.parseLottery, 'POST')

    # 排列三, 排列五
    url = "https://www.lottery.gov.cn/api/lottery_kj_detail_new.jspx?_ltype=5"
    yield scrapy.Request(url, self.parsePermutation, 'POST')

    # 双色球
    url = "https://api.xinti.com/chart/QueryPrizeDetailInfo"
    body = '''
      {
        "ClientSource": 3,
        "Param":{
          "GameCode": "SSQ"
        }
      }
    '''
    yield scrapy.Request(url, self.parseDraw, 'POST', None, body)

  # 大乐透
  def parseLottery(self, response):
    data = response.json()
    data = data[0]

    # 大乐透
    typ = 'lottery'
    result = LotteryResult(
      typ,
      data['lottery']['term'],
      data['lottery']['fTime'][0:10],
      '|'.join(data['codeNumber'])
    )

    details = []
    for i, item in enumerate(data['details']):
      detail = LotteryResultDetail(item.get('level'), item.get('piece'), item.get('money'))
      detail.add(data['detailsAdd'][i].get('piece'), data['detailsAdd'][i].get('money'))
      details.append(detail)
    result.setDetails(details)

    result.persist()

  # 排列三, 排列五
  def parsePermutation(self, response):
    data = response.json()
    data = data[0]

    issueNo = data['lottery']['term']
    openingDate = data['lottery']['fTime'][0:10]

    # 排列三
    typ = 'p3'
    result = LotteryResult(
      typ,
      issueNo,
      openingDate,
      '|'.join(data['codeNumber'])
    )

    details = []
    for i, item in enumerate(data['details']):
      detail = LotteryResultDetail(item.get('level'), item.get('piece'), item.get('money'))
      details.append(detail)

    result.setDetails(details)
    result.persist()

    # 排列五
    typ = 'p5'
    result = LotteryResult(
      typ,
      issueNo,
      openingDate,
      '|'.join(data['codeNumberPlw'])
    )

    details = []
    for i, item in enumerate(data['detailsPlw']):
      detail = LotteryResultDetail(item.get('level'), item.get('piece'), item.get('money'))
      details.append(detail)

    result.setDetails(details)
    result.persist()

  # 福彩 - 双色球
  def parseDraw(self, response):
    data = response.json()
    data = data['Value']

    typ = 'double-color'
    result = LotteryResult(
      typ,
      data['PreIssuseInfo']['IssuseNumber'].replace('-', ''),
      data['PreIssuseInfo']['AwardTime'],
      data['PreIssuseInfo']['WinNumber'].replace(',', '|')
    )

    details = []
    for item in data['BonusPoolList']:
      level = item.get('PrizeName')

      detail = LotteryResultDetail(level, str(item.get('WinCount')), str(item.get('SingleWinBonus')))
      details.append(detail)

    result.setDetails(details)
    result.persist()
